Application utilities
=====================

``HookMan`` offers a few utilities to help with the task to manage and handle plugins used by the application.

With ``HookMan`` you can:

- **Install Plugins**:
    Install a plugun by informing the path to where the ``.hmplugin`` is located.
- **Remove a Plugin**:
    Remove the plugin by informing the name of the plugin.
- **List all plugins availables**:
    Get a list of plugins with all the plugin details.
- **Get the status of all plugins**:
    Check if there are conflicts between them.

The method that list all plugins available return a list of ``PluginInfo``, for more details read the :ref:`plugin-info-api-section` API section.
